@@ -20,7 +20,10 @@ from Foundation import (
     NSData,
     NSError,
 )
-from CoreBluetooth import CBCharacteristicWriteWithResponse, CBCharacteristicWriteWithoutResponse
+from CoreBluetooth import (
+    CBCharacteristicWriteWithResponse,
+    CBCharacteristicWriteWithoutResponse,
+)
 
 from bleak.exc import BleakError
 
@@ -211,9 +214,7 @@ class PeripheralDelegate(NSObject):
     # Protocol Functions
 
     @objc.python_method
-    def did_discover_services(
-        self, peripheral: CBPeripheral, error: NSError
-    ) -> None:
+    def did_discover_services(self, peripheral: CBPeripheral, error: NSError) -> None:
         if error is not None:
             raise BleakError("Failed to discover services {}".format(error))
 
@@ -225,9 +226,7 @@ class PeripheralDelegate(NSObject):
     ) -> None:
         logger.debug("peripheral_didDiscoverServices_")
         self._event_loop.call_soon_threadsafe(
-            self.did_discover_services,
-            peripheral,
-            error,
+            self.did_discover_services, peripheral, error,
         )
 
     @objc.python_method
@@ -252,10 +251,7 @@ class PeripheralDelegate(NSObject):
     ):
         logger.debug("peripheral_didDiscoverCharacteristicsForService_error_")
         self._event_loop.call_soon_threadsafe(
-            self.did_discover_characteristics_for_service,
-            peripheral,
-            service,
-            error,
+            self.did_discover_characteristics_for_service, peripheral, service, error,
         )
 
     @objc.python_method
@@ -290,7 +286,11 @@ class PeripheralDelegate(NSObject):
 
     @objc.python_method
     def did_update_value_for_characteristic(
-        self, peripheral: CBPeripheral, characteristic: CBCharacteristic, error: NSError
+        self,
+        peripheral: CBPeripheral,
+        characteristic: CBCharacteristic,
+        value: bytes,
+        error: NSError,
     ):
         cUUID = characteristic.UUID().UUIDString()
         if error is not None:
@@ -300,7 +300,7 @@ class PeripheralDelegate(NSObject):
 
         notify_callback = self._characteristic_notify_callbacks.get(cUUID)
         if notify_callback:
-            notify_callback(cUUID, characteristic.value())
+            notify_callback(cUUID, value)
 
         logger.debug("Read characteristic value")
         event = self._characteristic_read_events.get(cUUID)
@@ -318,6 +318,7 @@ class PeripheralDelegate(NSObject):
             self.did_update_value_for_characteristic,
             peripheral,
             characteristic,
+            characteristic.value(),
             error,
         )
 
@@ -327,9 +328,7 @@ class PeripheralDelegate(NSObject):
     ):
         dUUID = descriptor.UUID().UUIDString()
         if error is not None:
-            raise BleakError(
-                "Failed to read characteristic {}: {}".format(dUUID, error)
-            )
+            raise BleakError("Failed to read descriptor {}: {}".format(dUUID, error))
 
         logger.debug("Read descriptor value")
         event = self._descriptor_read_events.get(dUUID)
@@ -343,10 +342,7 @@ class PeripheralDelegate(NSObject):
     ):
         logger.debug("peripheral_didUpdateValueForDescriptor_error_")
         self._event_loop.call_soon_threadsafe(
-            self.did_update_value_for_descriptor,
-            peripheral,
-            descriptor,
-            error,
+            self.did_update_value_for_descriptor, peripheral, descriptor, error,
         )
 
     @objc.python_method
@@ -372,10 +368,7 @@ class PeripheralDelegate(NSObject):
     ):
         logger.debug("peripheral_didWriteValueForCharacteristic_error_")
         self._event_loop.call_soon_threadsafe(
-            self.did_write_value_for_characteristic,
-            peripheral,
-            characteristic,
-            error,
+            self.did_write_value_for_characteristic, peripheral, characteristic, error,
         )
 
     @objc.python_method
@@ -398,10 +391,7 @@ class PeripheralDelegate(NSObject):
     ):
         logger.debug("peripheral_didWriteValueForDescriptor_error_")
         self._event_loop.call_soon_threadsafe(
-            self.did_write_value_for_descriptor,
-            peripheral,
-            descriptor,
-            error,
+            self.did_write_value_for_descriptor, peripheral, descriptor, error,
         )
 
     @objc.python_method
